@@ -1,4 +1,4 @@
-### $Id: reStruct.R,v 1.3 2001/01/10 19:04:03 bates Exp $
+### $Id: reStruct.R,v 1.4 2001/06/18 21:16:49 bates Exp $
 ###
 ###      Methods for the class of random-effects structures.
 ###
@@ -421,7 +421,7 @@ recalc.reStruct <-
 }
 
 solve.reStruct <-
-  function(a, b)
+  function(a, b, tol)
 {
   a[] <- lapply(a, solve)
   a
